@@ -25,12 +25,10 @@
 
 #include <errno.h>
 #include <fcntl.h>
-#include <qplatformdefs.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <KLazyLocalizedString>
 
 #ifdef HAVE_SOUNDCARD_H
 #include <soundcard.h>
@@ -40,7 +38,11 @@
 #endif
 #endif
 
-#include <QTimer>
+#include <klazylocalizedstring.h>
+
+#include <qplatformdefs.h>
+#include <qtimer.h>
+#include <qregularexpression.h>
 
 /*
   I am using a fixed MAX_MIXDEVS #define here.
@@ -371,7 +373,7 @@ int Mixer_OSS::readVolumeFromHW(const QString &id, shared_ptr<MixDevice> md)
                 // Muted is represented in OSS by value 0. We don't want to write the value 0 as a volume,
                 // but instead we only mark it muted (see setMuted() above).
 
-                for (const VolumeChannel &vc : qAsConst(vol.getVolumes()))
+                for (const VolumeChannel &vc : std::as_const(vol.getVolumes()))
                 {
                     long volOld = 0;
                     long volNew = 0;
@@ -470,9 +472,10 @@ int OSS_acceptsHotplugId(const QString &id)
     // The "mixer" one of these is taken as the canonical form.  The "card" and
     // "mixer" numbers are assumed to be the same, but this is not checked.
 
-    QRegExp rx("/card(\\d+)/mixer(\\d+)$");		// match sound card mixer device
-    if (!id.contains(rx)) return (-1);			// UDI not recognised
-    return (rx.cap(2).toInt());				// assume conversion succeeds
+    const QRegularExpression rx("/card(\\d+)/mixer(\\d+)$");
+    const QRegularExpressionMatch match = rx.match(id);	// match sound card mixer device
+    if (!match.hasCaptured(2)) return (-1);		// UDI not recognised
+    return (match.captured(2).toInt());			// assume conversion succeeds
 }
 
 
