@@ -24,13 +24,15 @@
 #include "kmixdockwidget.h"
 
 // Define this if KStatusNotifierItem::setOverlayIconByName() works.
-// As of March 2020 it appears to be not working, the base icon is
-// shown but with no overlay.
-//#define CAN_USE_ICON_OVERLAY	1
+// For KF5 as of March 2020 it appears to be not working, the base icon
+// is shown but with no overlay.  KF6 originally appeared to be fine but
+// currently as of October 2024 the overlay is not working again.
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#undef CAN_USE_ICON_OVERLAY
+#endif
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
-#include <QDesktopWidget>
 #include <QAction>
 #include <QGuiApplication>
 #include <QMenu>
@@ -40,7 +42,6 @@
 #endif // CAN_USE_ICON_OVERLAY
 
 #include <klocalizedstring.h>
-#include <kwindowsystem.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
 #include <kxmlguiwindow.h>
@@ -57,6 +58,7 @@ KMixDockWidget::KMixDockWidget(KXmlGuiWindow *parent)
     , _kmixMainWindow(parent)
     , _delta(0)
     , _dockMuteAction(nullptr)
+    , _dockRestoreAction(nullptr)
 {
     setToolTipIconByName("kmix");
     setTitle(i18n("Volume Control"));
@@ -107,7 +109,16 @@ KMixDockWidget::~KMixDockWidget()
 
 void KMixDockWidget::createWidgets()
 {
-	if (_dockPopupWrapper==nullptr) _dockPopupWrapper = new QMenu(_kmixMainWindow);
+	if (_dockPopupWrapper==nullptr)
+	{
+		_dockPopupWrapper = new QMenu(_kmixMainWindow);
+		_dockPopupWrapper->setAttribute(Qt::WA_X11NetWmWindowTypeDock);
+		_dockPopupWrapper->setWindowFlag(Qt::WindowStaysOnTopHint);
+		// TODO KF6: Does this work to skip the taskbar and pager?
+		// See https://stackoverflow.com/questions/4055506/qt-hide-taskbar-item
+		// which suggests using Qt::SubWindow instead.
+		_dockPopupWrapper->setWindowFlag(Qt::Popup);
+	}
 	else _dockPopupWrapper->removeAction(_dockWidgetAction);
 
 	delete _dockWidgetAction;			// also deletes '_dockView' if it exists
@@ -177,6 +188,17 @@ void KMixDockWidget::createMenuActions()
         menu->addAction(_dockMuteAction);
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    // "Show Main Window" action
+    //
+    // The KStatusNotifierItem does not create or manage a "Restore" action
+    // because there is no associated window, so we must do that ourselves.
+    _dockRestoreAction = new KToggleAction(i18n("Show Mixer Window"), this);
+    _dockRestoreAction->setIcon(QIcon::fromTheme("show-mixer"));
+    connect(_dockRestoreAction, &QAction::triggered, this, [this]() { activate(QPoint()); });
+    menu->addAction(_dockRestoreAction);
+#endif
+
     // "Select Master Channel" dialog
     QAction *action = _kmixMainWindow->actionCollection()->action("select_master");
     if (action!=nullptr) menu->addAction(action);
@@ -184,6 +206,7 @@ void KMixDockWidget::createMenuActions()
     // "Configure KMix" settings
     action = _kmixMainWindow->actionCollection()->action(KStandardAction::name(KStandardAction::Preferences));
     if (action!=nullptr) menu->addAction(action);
+
 }
 
 
@@ -335,6 +358,9 @@ void KMixDockWidget::activate(const QPoint &pos)
 		return;
 	}
 
+	shared_ptr<MixDevice> md = MixerToolBox::getGlobalMasterMD();
+	if (md.get()==nullptr) return;			// no mixer devices, do not show
+
 	createWidgets();				// recreate the popup
 
 	//_dockView->show(); // TODO cesken check: this should be automatic
@@ -344,22 +370,26 @@ void KMixDockWidget::activate(const QPoint &pos)
 	_dockPopupWrapper->adjustSize();
 
 	int x = pos.x() - _dockPopupWrapper->width() / 2;
-	if (x < 0)
-		x = pos.x();
+	if (x < 0) x = pos.x();
 	int y = pos.y() - _dockPopupWrapper->height() / 2;
-	if (y < 0)
-		y = pos.y();
+	if (y < 0) y = pos.y();
 
 	// Now handle Multihead displays. And also make sure that the dialog is not
 	// moved out-of-the screen on the right (see Bug 101742).
 	const QScreen *screen = QGuiApplication::screenAt(pos);
 	if (screen==nullptr) return;
-	const QRect vScreenSize = screen->availableGeometry();
+	// Pretend that the screen has a border all around it, so that
+	// the popup is not jammed up against the screen edge and will
+	// leave at least a part of the panel uncovered.
+	const QRect vScreenSize = screen->availableGeometry().adjusted(32, 32, -32, -32);
 
-	if ((x + _dockPopupWrapper->width()) > (vScreenSize.width() + vScreenSize.x()))
+	const int myWidth = _dockPopupWrapper->width();
+	const int myHeight = _dockPopupWrapper->height();
+
+	if ((x + myWidth) > (vScreenSize.width() + vScreenSize.x()))
 	{
 		// move horizontally, so that it is completely visible
-		x = vScreenSize.width() + vScreenSize.x() - _dockPopupWrapper->width() - 1;
+		x = vScreenSize.width() + vScreenSize.x() - myWidth - 1;
 		qCDebug(KMIX_LOG) << "Multihead: (case 1) moving to" << x << "," << y;
 	}
 	else if (x < vScreenSize.x())
@@ -369,21 +399,19 @@ void KMixDockWidget::activate(const QPoint &pos)
 		qCDebug(KMIX_LOG) << "Multihead: (case 2) moving to" << x << "," << y;
 	}
 
-	if ((y + _dockPopupWrapper->height()) > (vScreenSize.height() + vScreenSize.y()))
+	if ((y + myHeight) > (vScreenSize.height() + vScreenSize.y()))
 	{
-		// move horizontally, so that it is completely visible
-		y = vScreenSize.height() + vScreenSize.y() - _dockPopupWrapper->height() - 1;
+		// move vertically, so that it is completely visible
+		y = vScreenSize.height() + vScreenSize.y() - myHeight - 1;
 		qCDebug(KMIX_LOG) << "Multihead: (case 3) moving to" << x << "," << y;
 	}
 	else if (y < vScreenSize.y())
 	{
-		// horizontally out-of bound
+		// vertically out-of bound
 		y = vScreenSize.y();
 		qCDebug(KMIX_LOG) << "Multihead: (case 4) moving to" << x << "," << y;
 	}
 
-	KWindowSystem::setType(_dockPopupWrapper->winId(), NET::Dock);
-	KWindowSystem::setState(_dockPopupWrapper->winId(), NET::KeepAbove | NET::SkipTaskbar | NET::SkipPager);
 	_dockPopupWrapper->show();
 	_dockPopupWrapper->move(x, y);
 }
@@ -439,6 +467,8 @@ void KMixDockWidget::trayWheelEvent(int delta, Qt::Orientation wheelOrientation)
 
 void KMixDockWidget::dockMute()
 {
+// TODO: should go through KMixWindow::slotMute()
+// so that the OSD is shown.
     shared_ptr<MixDevice> md = MixerToolBox::getGlobalMasterMD();
     if (md.get()!=nullptr)
     {
@@ -477,6 +507,12 @@ void KMixDockWidget::contextMenuAboutToShow()
         }
     }
 
+    // State of "Show Main Window".
+    if (_dockRestoreAction!=nullptr)
+    {
+	_dockRestoreAction->setChecked(!_kmixMainWindow->isHidden());
+    }
+
     // Enable/disable "Select Master Channel".
     // It will only be disabled if there are no sound devices available at all.
     QAction *action = _kmixMainWindow->actionCollection()->action("select_master");
